@@ -136,7 +136,6 @@ class c_commandarg: #根据命令行参数调用模块及显示相应help
         for g in gg:
             if (inspect.isfunction(gg[g]) or inspect.isclass(gg[g])) and gg[g].__doc__!=None:
                 c_commandarg.tcmd[g]=gg[g]
-        c_commandarg.tcmd["install"]=c_commandarg.tcmd.get("install",install)
     def main(self):
         if len(sys.argv)>1:
             cmd=sys.argv[1]
@@ -216,50 +215,6 @@ class webapi(object):
             print(jg)
         return jg
 
-def install():
-    '''更新此脚本到服务器，参数指定 0生产1预生产2测试,默认是2；要发布的文件，不指定则发布自己'''
-    runlevel,fn=getarg("0",sys.argv[0])
-    api=webapi()
-    if not os.path.exists(fn):
-        swexit(1,"未找到指定的文件%s" %(fn))
-    if os.path.isfile(fn):
-        api.up(fn)
-    else:
-        for f in os.listdir(fn):
-            api.up("%s/%s" %(fn,f))
-
-class cks(object):
-    '''检查脚本和服务器上的脚本的差异，参数:0生产1预生产2测试,默认是2; 脚本名称（不指定则检查所有）'''
-    def __init__(self):
-        runlevel,fn=getarg("0",".")
-        self.api=webapi()
-        if not os.path.exists(fn):
-            swexit(1,"未找到指定的文件%s" %(fn))
-        if os.path.isfile(fn):
-            self.ck(fn)
-        else:
-            for f in os.listdir(fn):
-                self.ck("%s/%s" %(fn,f))
-    def ck(self,f):
-        import difflib
-        if os.path.isdir(f):return
-        print(f,end="  ")
-        jg=self.api.down(f)
-        if jg["code"]==0:
-            data=jg["data"]
-            if data["md5"]==filemd5(f):
-                print("")
-            else:
-                redp("文件md5:%s 数据库中文件md5:%s" %(filemd5(f),data["md5"]))
-                if f.endswith("py"):
-                    diff=difflib.Differ()
-                    n1=base64.b64decode(data["script"]).decode("utf8")
-                    with open(f,"rb") as f:
-                        n2=f.read().decode("utf8")
-                    #print("\n".join(diff.compare(n1.split("\n"),n2.split("\n"))))
-                    print("\n".join(difflib.context_diff(n1.split("\n"),n2.split("\n"))))
-                    
-
 def redp(s):
     print("\x1b[0;31;40m%s\x1b[0m" %(s))
 
